==> xwiki-platform-extension-api-3.3-sources.jar: org/xwiki/extension/unmodifiable/UnmodifiableLocalExtensionFile.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.extension.unmodifiable;

import org.xwiki.extension.LocalExtensionFile;

/**
 * Provide a readonly access to a local extension file.
 * 
 * @param <T> the extension type
 * @version $Id$
 */
public class UnmodifiableLocalExtensionFile<T extends LocalExtensionFile> extends UnmodifiableExtensionFile<T>
    implements LocalExtensionFile
{
    /**
     * @param file he wrapped file
     */
    public UnmodifiableLocalExtensionFile(T file)
    {
        super(file);
    }

    // LocalExtensionFile

    @Override
    public String getName()
    {
        return getFile().getName();
    }

    @Override
    public String getAbsolutePath()
    {
        return getFile().getAbsolutePath();
    }
}

==> xwiki-platform-extension-api-3.5.1-sources.jar: org/xwiki/extension/unmodifiable/UnmodifiableLocalExtensionFile.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.extension.unmodifiable;

import org.xwiki.extension.LocalExtensionFile;

/**
 * Provide a readonly access to a local extension file.
 * 
 * @param <T> the extension type
 * @version $Id$
 */
public class UnmodifiableLocalExtensionFile<T extends LocalExtensionFile> extends UnmodifiableExtensionFile<T>
    implements LocalExtensionFile
{
    /**
     * @param file he wrapped file
     */
    public UnmodifiableLocalExtensionFile(T file)
    {
        super(file);
    }

    // LocalExtensionFile

    @Override
    public String getName()
    {
        return getWrapped().getName();
    }

    @Override
    public String getAbsolutePath()
    {
        return getWrapped().getAbsolutePath();
    }
}
